==> nonebot_plugin_gshisbanner-0.2.0.tar.gz: nonebot_plugin_gshisbanner-0.2.0/README.md <==
<div align="center">
  <a href="https://v2.nonebot.dev/store"><img src="https://ghproxy.com/https://github.com/A-kirami/nonebot-plugin-template/blob/resources/nbp_logo.png" width="180" height="180" alt="NoneBotPluginLogo"></a>
  <br>
  <p><img src="https://ghproxy.com/https://github.com/A-kirami/nonebot-plugin-template/blob/resources/NoneBotPlugin.svg" width="240" alt="NoneBotPluginText"></p>
</div>

<div align="center">

# nonebot-plugin-gshisbanner

_✨ NoneBot 插件简单描述 ✨_
本插件用于在机器人上查询原神历史卡池信息

<a href="./LICENSE">
    <img src="https://img.shields.io/github/license/forchannot/nonebot-plugin-gshisbanner.svg" alt="license">
</a>
<a href="https://pypi.python.org/pypi/nonebot-plugin-gshisbanner">
    <img src="https://img.shields.io/pypi/v/nonebot-plugin-gshisbanner.svg" alt="pypi">
</a>
<img src="https://img.shields.io/badge/python-3.8+-blue.svg" alt="python">

</div>

## 📖 介绍

本插件用于在机器人上查询原神历史卡池信息

## 💿 安装

<details>
<summary>使用 nb-cli 安装</summary>
在 nonebot2 项目的根目录下打开命令行, 输入以下指令即可安装

    nb plugin install nonebot-plugin-gshisbanner
</details>

<details>
<summary>pip</summary>

    pip install nonebot-plugin-gshisbanner
打开 nonebot2 项目根目录下的 `pyproject.toml` 文件, 在 `[tool.nonebot]` 部分追加写入

    plugins = ["nonebot_plugin_gshisbanner"]
</details>

## ⚙️ 配置

暂无

## 🎉 使用
### 指令表
| 指令 | 权限 | 需要@ | 范围 | 说明 |
|:-----:|:----:|:----:|:----:|:----:|
| 历史卡池 | ALL | 否 | ALL  | XX历史卡池 |
| 刷新历史卡池 | 管理员以上 | 是 | ALL | 刷新历史卡池 |
### 效果图
![image](https://cdn.staticaly.com/gh/forchannot/mypicgo@main/20230315/image.40vk11yurwc0.jpg)

![image](https://cdn.staticaly.com/gh/forchannot/mypicgo@main/20230315/image.50gyt4mcjc40.jpg)

==> nonebot_plugin_gshisbanner-0.2.2.tar.gz: nonebot_plugin_gshisbanner-0.2.2/README.md <==
<div align="center">
  <a href="https://v2.nonebot.dev/store"><img src="https://ghproxy.com/https://github.com/A-kirami/nonebot-plugin-template/blob/resources/nbp_logo.png" width="180" height="180" alt="NoneBotPluginLogo"></a>
  <br>
  <p><img src="https://ghproxy.com/https://github.com/A-kirami/nonebot-plugin-template/blob/resources/NoneBotPlugin.svg" width="240" alt="NoneBotPluginText"></p>
</div>

<div align="center">

# nonebot-plugin-gshisbanner

_✨ 本插件用于在机器人上查询原神历史卡池信息 ✨_

<a href="./LICENSE">
    <img src="https://img.shields.io/github/license/forchannot/nonebot-plugin-gshisbanner.svg" alt="license">
</a>
<a href="https://pypi.python.org/pypi/nonebot-plugin-gshisbanner">
    <img src="https://img.shields.io/pypi/v/nonebot-plugin-gshisbanner.svg" alt="pypi">
</a>
<img src="https://img.shields.io/badge/python-3.8+-blue.svg" alt="python">

</div>

## 📖 介绍

本插件用于在机器人上查询原神历史卡池信息

## 💿 安装

<details>
<summary>使用 nb-cli 安装</summary>
在 nonebot2 项目的根目录下打开命令行, 输入以下指令即可安装

    nb plugin install nonebot-plugin-gshisbanner
</details>

<details>
<summary>pip</summary>

    pip install nonebot-plugin-gshisbanner
打开 nonebot2 项目根目录下的 `pyproject.toml` 文件, 在 `[tool.nonebot]` 部分追加写入

    plugins = ["nonebot_plugin_gshisbanner"]
</details>

## ⚙️ 配置

暂无

## 🎉 使用
### 指令表
| 指令 | 权限 | 需要@ | 范围 | 说明 |
|:-----:|:----:|:----:|:----:|:----:|
| 历史卡池 | ALL | 否 | ALL  | XX历史卡池 |
| 刷新历史卡池/别名 | 管理员以上 | 是 | ALL | 刷新历史卡池或别名 |
### 效果图
![image](https://cdn.staticaly.com/gh/forchannot/mypicgo@main/20230315/image.40vk11yurwc0.jpg)

![image](https://cdn.staticaly.com/gh/forchannot/mypicgo@main/20230315/image.50gyt4mcjc40.jpg)
